..
      Copyright 2015 IBM
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Developer Guide
===============

In the Developer Guide, you will find information on how to develop for
Networking-PowerVM and how it interacts with Neutron. You will also find
information on setup and usage of Networking-PowerVM.


Internals and Programming
-------------------------
.. toctree::
    :maxdepth: 3

    development_environment
    usage


Testing
-------
.. toctree::
    :maxdepth: 3

    testing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

